@@ -173,8 +173,7 @@ def init() -> Iterable[AtomicIterable]:
 @process_atoms(load_template=None)
 def config(config_file: Literal["local", "global"]) -> Iterable[AtomicIterable]:
     """Edit configuration files. This opens the corresponding file in your
-    $EDITOR. By default, edit the local template file: this requires the working
-    directory to be texproject directory.
+    $EDITOR. By default, edit the global configuration file.
     """
     yield FileEditor(config_file)
 
@@ -239,12 +238,12 @@ def import_(
     gitignore: bool,
     pre_commit: bool,
 ) -> Iterable[AtomicIterable]:
-    """Import macro, citation, and format files. This command will replace existing
+    """Import macro, citation, and style files. This command will replace existing
     files. Note that this command does not import the files into the main .tex file.
 
-    The --macro-path and --citation-path allow macro and citation files to be specified
-    as paths to existing files. For example, this enables imports which are not
-    installed in the texproject data directory.
+    The --{macro, citation, style}-path options allow macro and citation files to be
+    specified as paths to existing files. This enables imports which are not installed
+    in the texproject data directory.
     """
     for mode, names, paths in [
         ("macro", macros, macro_paths),
@@ -275,7 +274,7 @@ def import_(
 @process_atoms()
 def validate(pdf: Optional[Path], logfile: Optional[Path]) -> Iterable[AtomicIterable]:
     """Check for compilation errors. Compilation is performed by the 'latexmk' command.
-    Save the resulting pdf with the '--output' argument, or the log file with the
+    Save the resulting pdf with the '--pdf' argument, or the log file with the
     '--logfile' argument. These options, if specified, will overwrite existing files.
     """
     yield LatexCompiler(
@@ -407,17 +406,6 @@ def edit() -> Iterable[AtomicIterable]:
     yield InfoFileWriter()
 
 
-@template.command("refresh")
-@click.option("--force/--no-force", "-f/-F", default=False, help="overwrite files")
-@process_atoms()
-def refresh(force: bool) -> Iterable[AtomicIterable]:
-    """Reload template files. If --force is specified, overwrite local template files
-    with new versions from the template repository, if possible.
-    """
-    yield TemplateDictLinker(LinkCommand.replace if force else LinkCommand.copy)
-    yield InfoFileWriter()
-
-
 @cli.group()
 def git() -> None:
     """Manage git and GitHub repositories."""
@@ -473,10 +461,10 @@ def git_init(
     correctly. This command also creates a GitHub action with automatically compiles and
     releases the main .pdf file for tagged releases.
 
-    If you have specified 'github.archive', the GitHub action will also automatically
-    push the build files to the corresponding folder in the specified repository. In
-    order for this to work, you must provide an access token with at least repo
-    privileges. This can be done (in order of priority) by
+    If you have specified 'github.archive' in your configuration, the GitHub action
+    will also automatically push the build files to the corresponding folder in the
+    specified repository. In order for this to work, you must provide an access token
+    with at least repo privileges. This can be done (in order of priority) by
 
     1) setting the environment variable $API_TOKEN_GITHUB, or
 
@@ -530,6 +518,17 @@ def clean() -> Iterable[AtomicIterable]:
     yield CleanProject()
 
 
+@template.command("util")
+@click.option("--force/--no-force", "-f/-F", default=False, help="overwrite files")
+@process_atoms()
+def refresh(force: bool) -> Iterable[AtomicIterable]:
+    """Reload template files. If --force is specified, overwrite local template files
+    with new versions from the template repository, if possible.
+    """
+    yield TemplateDictLinker(LinkCommand.replace if force else LinkCommand.copy)
+    yield InfoFileWriter()
+
+
 @util.command()
 def show_config():
     """"""
@@ -578,8 +577,9 @@ def show(
     pre_commit: bool,
     diff: bool,
 ) -> Iterable[AtomicIterable]:
-    """Import macro, citation, and format files. This command will replace existing
-    files. Note that this command does not import the files into the main .tex file.
+    """Print macro, citation, and style files to STDOUT. The --diff option displays
+    the difference between the file and the current file which would be overwritten if
+    imported.
 
     The --macro-path and --citation-path allow macro and citation files to be specified
     as paths to existing files. For example, this enables imports which are not
