@@ -128,6 +128,8 @@ class FileEditor(AtomicIterable):
 
         try:
             click.edit(filename=str(fpath))
+            if self.config_file == "template":
+                template_dict.load_from_source()
             yield RuntimeClosure(FORMAT_MESSAGE.edit(fpath), *SUCCESS)
         except click.UsageError:
             yield RuntimeClosure(
